@@ -39,6 +39,7 @@ use App::CELL qw( $CELL $log $meta $site );
 use App::Dochazka::REST::ConnBank qw( $dbix_conn );
 use App::Dochazka::REST::Model::Employee;
 use App::Dochazka::REST::Model::Shared qw(
+    load_multiple
     split_tsrange
 );
 use App::Dochazka::REST::Util::Date qw(
@@ -382,7 +383,9 @@ sub fillup {
                 'DOCHAZKA_TEMPINTVLS_INSERT_OK', 
                 payload => {
                     intervals => $intvls,
-                    tiid => $self->{tiid},
+                    aid => $self->aid,
+                    eid => $self->eid,
+                    tiid => $self->tiid,
                 }
             );
         } );
@@ -393,6 +396,109 @@ sub fillup {
 }
 
 
+=head2 commit
+
+Takes a PARAMHASH containing a C<DBIx::Connector> object and, optionally, a
+C<dry_run> boolean value that defaults to 0.
+
+If C<dry_run> is true, merely SELECTs intervals from the tempintvls table
+corresponding to the tsrange (already vetted and stored in the object by
+calling C<_vet_tsrange>). This SELECT includes partial intervals (if any) at
+the beginning and end of the tsrange (using PostgreSQL intersection operator).
+
+If C<dry_run> is false, all the intervals from the SELECT are INSERTed into the
+intervals table.
+
+=cut
+
+sub commit {
+    my $self = shift;
+    my ( %ARGS ) = validate( @_, {
+        dbix_conn => { isa => 'DBIx::Connector' },
+        dry_run => { type => SCALAR, default => 0 },
+    } );
+    my $status;
+
+    my $sql = $ARGS{dry_run}
+        ? $site->SQL_TEMPINTVLS_SELECT_EXCLUSIVE
+        : $site->SQL_TEMPINTVLS_SELECT_EXCLUSIVE; # FIXME
+
+    return load_multiple(
+        conn => $ARGS{dbix_conn},
+        class => 'App::Dochazka::REST::Model::Interval',
+        sql => $sql,
+        keys => [ $self->{tsrange} ],
+    );
+}
+
+
+=head2 update
+
+There is no update method for tempintvls. Instead, delete and re-create.
+
+
+=head2 delete
+
+Instance method. Once we are done with the scratch intervals, they can be deleted.
+Returns a status object.
+
+=cut
+
+sub delete {
+    my $self = shift;
+    my ( %ARGS ) = validate( @_, {
+        dbix_conn => { isa => 'DBIx::Connector' },
+    } );
+
+    my $status;
+    try {
+        $ARGS{dbix_conn}->run( fixup => sub {
+            my $sth = $_->prepare( $site->SQL_TEMPINTVLS_DELETE );
+            $sth->bind_param( 1, $self->tiid );
+            $sth->execute;
+            my $rows = $sth->rows;
+            if ( $rows > 0 ) {
+                $status = $CELL->status_ok( 'DOCHAZKA_RECORDS_DELETED', args => [ $rows ], count => $rows );
+            } elsif ( $rows == 0 ) {
+                $status = $CELL->status_warn( 'DOCHAZKA_RECORDS_DELETED', args => [ $rows ], count => $rows );
+            } else {
+                die( "\$sth->rows returned a weird value $rows" );
+            }
+        } );
+    } catch {
+        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
+    };
+    return $status;
+}
+
+
+
+=head1 FUNCTIONS
+
+=head2 _next_tiid
+
+Get next value from the temp_intvl_seq sequence
+
+=cut
+
+sub _next_tiid {
+    my $val;
+    my $status;
+    try {
+        $dbix_conn->run( fixup => sub {
+            ( $val ) = $_->selectrow_array( $site->SQL_NEXT_TIID );
+        } );    
+    } catch {
+        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
+    };
+    if ( $status ) {
+        $log->crit( $status->text );
+        return;
+    }
+    return $val;
+}
+
+
 =head2 Days_to_Date
 
 Missing function in L<Date::Calc>
@@ -436,76 +542,6 @@ sub _init_lower_sched_hash {
 
 
 
-=head2 update
-
-There is no update method for tempintvls. Instead, delete and re-create.
-
-
-=head2 delete
-
-Instance method. Once we are done with the scratch intervals, they can be deleted.
-Returns a status object.
-
-=cut
-
-sub delete {
-    my $self = shift;
-    my ( $conn ) = validate_pos( @_,
-        { isa => 'DBIx::Connector' }
-    );
-
-    my $status;
-    try {
-        $conn->run( fixup => sub {
-            my $sth = $_->prepare( $site->SQL_TEMPINTVLS_DELETE );
-            $sth->bind_param( 1, $self->ssid );
-            $sth->execute;
-            my $rows = $sth->rows;
-            if ( $rows > 0 ) {
-                $status = $CELL->status_ok( 'DOCHAZKA_RECORDS_DELETED', args => [ $rows ] );
-            } elsif ( $rows == 0 ) {
-                $status = $CELL->status_warn( 'DOCHAZKA_RECORDS_DELETED', args => [ $rows ] );
-            } else {
-                die( "\$sth->rows returned a weird value $rows" );
-            }
-        } );
-    } catch {
-        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
-    };
-    return $status;
-}
-
-
-
-
-
-=head1 FUNCTIONS
-
-=head2 _next_tiid
-
-Get next value from the temp_intvl_seq sequence
-
-=cut
-
-sub _next_tiid {
-    my $val;
-    my $status;
-    try {
-        $dbix_conn->run( fixup => sub {
-            ( $val ) = $_->selectrow_array( $site->SQL_NEXT_TIID );
-        } );    
-    } catch {
-        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ] );
-    };
-    if ( $status ) {
-        $log->crit( $status->text );
-        return;
-    }
-    return $val;
-}
-
-
-
 =head1 AUTHOR
 
 Nathan Cutler, C<< <presnypreklad@gmail.com> >>
